@@ -2,8 +2,6 @@ import locale
 import re
 import sys
 
-from PySide6.QtCore import QProcessEnvironment
-
 from configparser import ConfigParser, SectionProxy
 from enum import IntEnum, auto
 from logging import critical
@@ -11,8 +9,6 @@ from logging.config import dictConfig
 from pathlib import Path
 from uuid import UUID, uuid4
 
-from phystool.physql import physql_db
-
 
 try:
     locale.setlocale(locale.LC_ALL, "fr_CH.UTF-8")
@@ -34,7 +30,6 @@ class MyConfig:
         MISSING_DB_CONF = auto()
         MISSING_DB = auto()
         MISSING_DB_DIR = auto()
-        MISSING_SQL_FILE = auto()
         MISSING_KEY_IN_CONFIGURATION_FILE = auto()
         MISSING_PDB_TYPE = auto()
         MISSING_DOCUMENTCLASS_FILE = auto()
@@ -115,8 +110,6 @@ class DBConf:
         self.EDITABLE = section.get("editable", False)
         self.SHARED = section.get("shared", False)
         self.PHYSTEX = self.DB_DIR / "phystex"
-        self._env: dict[str, str]
-        self._qtenv: QProcessEnvironment
 
     def __str__(self) -> str:
         return f"{self.__class__.__name__}({self.DB_DIR})"
@@ -136,11 +129,10 @@ class DBConf:
                     re.compile(conf[section_name]["pattern"]),
                     conf[section_name].getboolean("standalone", False),
                 )
-                for section_name in conf.sections()
+                for section_name in sorted(conf.sections())
                 if section_name.startswith("pdb-type=")
             }
-            self.VALID_PDB_TYPES = sorted(self.PDB_TYPES.keys())
-            if not self.VALID_PDB_TYPES:
+            if not self.PDB_TYPES:
                 return MyConfig.Status.MISSING_PDB_TYPE
 
             documentclass = conf["phystool"]["auto_latex"]
@@ -156,26 +148,8 @@ class DBConf:
             )
         except KeyError:
             return MyConfig.Status.MISSING_KEY_IN_CONFIGURATION_FILE
-
-        if not physql_db.setup(self.DB_DIR / ".physql.sqlite"):
-            return MyConfig.Status.MISSING_SQL_FILE
         return MyConfig.Status.READY
 
-    def _load_env(self) -> None:
-        self._qtenv = QProcessEnvironment.systemEnvironment()
-        self._qtenv.insert("TEXINPUTS", f":{self.PHYSTEX}:")
-        self._env = {key: self._qtenv.value(key) for key in self._qtenv.keys()}
-
-    def env(self) -> dict[str, str]:
-        if not hasattr(self, "_env"):
-            self._load_env()
-        return self._env
-
-    def qtenv(self) -> QProcessEnvironment:
-        if not hasattr(self, "_qtenv"):
-            self._load_env()
-        return self._qtenv
-
     def template(self, uuid: UUID) -> str:
         return self._template.format(uuid=uuid)
 
@@ -257,6 +231,11 @@ LOGGER_FILE = {
     "level": config.DEFAULT_LOGLEVEL,
     "propagate": False,
 }
+LOGGER_ALCHEMY = {
+    "handlers": ["file_handler"],
+    "level": "WARN",
+    "propagate": False,
+}
 LOGGING_CONFIG = {
     "version": 1,
     "disable_existing_loggers": True,
@@ -293,9 +272,10 @@ LOGGING_CONFIG = {
         "phystool": LOGGER_BOTH,
         "pytex": LOGGER_BOTH,
         "qt": LOGGER_FILE,
-        "sqlalchemy": LOGGER_FILE,
+        "sqlalchemy": LOGGER_ALCHEMY,
         "tags": LOGGER_BOTH,
     },
 }
 
+# TODO : fix sql log verbosity in production
 dictConfig(LOGGING_CONFIG)
