@@ -1,4 +1,5 @@
 import re
+import sys
 from logging import getLogger
 from typing import Generator
 from math import pi, sqrt, exp, log2, log
@@ -339,7 +340,7 @@ class PyTex:
     ) -> Generator[tuple[str, str], None, None]:
         """Should not define any variable to avoid conflict with pycode"""
         try:
-            exec(init_block)
+            exec(init_block, locals=sys._getframe(0).f_locals)
         except SyntaxError as xcpt:
             msg = getattr(xcpt, "message", repr(xcpt))
             logger.error(f"SyntaxError: {msg} in {self.tex_file.stem}")
