@@ -1,9 +1,9 @@
 from logging import getLogger
 from pathlib import Path
 from collections.abc import Callable
-from typing import cast, override
+from typing import cast
 
-from PySide6.QtCore import Slot
+from PySide6.QtCore import Slot, QProcessEnvironment
 from PySide6.QtWidgets import QDockWidget, QPlainTextEdit
 
 from phystool.config import config
@@ -17,6 +17,8 @@ logger = getLogger(__name__)
 
 
 class QPdfLatex(QManagedProcess):
+    _ENVIRONMENT: QProcessEnvironment | None = None
+
     def __init__(
         self,
         pdb_file: PDBFile,
@@ -28,6 +30,12 @@ class QPdfLatex(QManagedProcess):
         self._status = self.Status.PENDING
         self._post_compilation_hook = post_compilation_hook
 
+    def _get_env(self) -> QProcessEnvironment:
+        if self.__class__._ENVIRONMENT is None:
+            self.__class__._ENVIRONMENT = QProcessEnvironment.systemEnvironment()
+            self.__class__._ENVIRONMENT.insert("TEXINPUTS", f":{config.db.PHYSTEX}:")
+        return self.__class__._ENVIRONMENT
+
     def __str__(self) -> str:
         return f"{self.__class__.__name__} <{self._pdb_file.uuid}>"
 
@@ -45,7 +53,7 @@ class QPdfLatex(QManagedProcess):
         cmd = PdfLatex.compilation_command(self._tmp_tex_file)
         self.setProgram(cmd[0])
         self.setArguments(cmd[1:])
-        self.setProcessEnvironment(config.db.qtenv())
+        self.setProcessEnvironment(self._get_env())
         self.finished.connect(self._handle_exit)
 
     @Slot(int)
